@@ -32,7 +32,7 @@ from gi.repository import Vte
 
 import libvirt
 
-from virtManager.baseclass import vmmGObject
+from .baseclass import vmmGObject
 
 
 class ConsoleConnection(vmmGObject):
@@ -205,8 +205,9 @@ class LibvirtConsoleConnection(ConsoleConnection):
         name = dev and dev.alias.name or None
         logging.debug("Opening console stream for dev=%s alias=%s",
                       dev, name)
-        if not name:
-            raise RuntimeError(_("Cannot open a device with no alias name"))
+        # libxl doesn't set aliases, their open_console just defaults to
+        # opening the first console device, so don't force prescence of
+        # an alias
 
         stream = self.conn.get_backend().newStream(libvirt.VIR_STREAM_NONBLOCK)
         self.vm.open_console(name, stream)
@@ -320,13 +321,12 @@ class vmmSerialConsole(vmmGObject):
         self.error_label = None
         self.init_ui()
 
-        self.vm.connect("status-changed", self.vm_status_changed)
+        self.vm.connect("state-changed", self.vm_status_changed)
 
     def init_terminal(self):
         self.terminal = Vte.Terminal()
         self.terminal.set_scrollback_lines(1000)
         self.terminal.set_audible_bell(False)
-        self.terminal.set_visible_bell(True)
 
         self.terminal.connect("button-press-event", self.show_serial_rcpopup)
         self.terminal.connect("commit", self.console.send_data, self.terminal)
@@ -412,8 +412,8 @@ class vmmSerialConsole(vmmGObject):
 
         return False
 
-    def vm_status_changed(self, src_ignore, oldstatus_ignore, status):
-        if status in [libvirt.VIR_DOMAIN_RUNNING]:
+    def vm_status_changed(self, vm):
+        if vm.status() in [libvirt.VIR_DOMAIN_RUNNING]:
             self.open_console()
         else:
             self.console.close()
