@@ -25,13 +25,16 @@ import ConfigParser
 import os
 
 
-cfg = ConfigParser.ConfigParser()
+_cfg = ConfigParser.ConfigParser()
 _filepath = os.path.abspath(__file__)
 _srcdir = os.path.abspath(os.path.join(os.path.dirname(_filepath), ".."))
-cfgpath = os.path.join(os.path.dirname(_filepath), "cli.cfg")
+_cfgpath = os.path.join(os.path.dirname(_filepath), "cli.cfg")
+if os.path.exists(_cfgpath):
+    _cfg.read(_cfgpath)
+
 _istest = "VIRTINST_TEST_SUITE" in os.environ
-if os.path.exists(cfgpath):
-    cfg.read(cfgpath)
+_running_from_srcdir = os.path.exists(
+    os.path.join(_srcdir, "tests", "clitest.py"))
 
 
 def _split_list(commastr):
@@ -42,7 +45,7 @@ def _get_param(name, default):
     if _istest:
         return default
     try:
-        return cfg.get("config", name)
+        return _cfg.get("config", name)
     except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
         return default
 
@@ -66,32 +69,44 @@ def _setup_gsettings_path(schemadir):
         raise RuntimeError("Failed to compile local gsettings schemas")
 
 
-__version__ = "1.1.0"
+__version__ = "1.2.1"
 
-__snapshot__ = 0
 
-_usr_version = _get_param("pkgversion", "")
-if _usr_version is not None and _usr_version != "":
-    __version__ = _usr_version
+class _CLIConfig(object):
+    def __init__(self):
+        self.cfgpath = _cfgpath
+        self.version = __version__
 
-# We should map this into the config somehow but I question if anyone cares
-prefix = _get_param("prefix", "/usr/local")
-gettext_dir = os.path.join(prefix, "share", "locale")
-install_asset_dir = os.path.join(prefix, "share", "virt-manager")
-if os.getcwd() == _srcdir:
-    asset_dir = _srcdir
-    icon_dir = os.path.join(_srcdir, "data")
-    _setup_gsettings_path(icon_dir)
-else:
-    asset_dir = install_asset_dir
-    icon_dir = os.path.join(asset_dir, "icons")
+        self.default_qemu_user = _get_param("default_qemu_user", "root")
+        self.stable_defaults = bool(int(_get_param("stable_defaults", "0")))
 
-default_qemu_user = _get_param("default_qemu_user", "root")
-stable_defaults = bool(int(_get_param("stable_defaults", "0")))
+        self.preferred_distros = _split_list(
+            _get_param("preferred_distros", ""))
+        self.hv_packages = _split_list(_get_param("hv_packages", ""))
+        self.askpass_package = _split_list(_get_param("askpass_packages", ""))
+        self.libvirt_packages = _split_list(_get_param("libvirt_packages", ""))
+        self.default_graphics = _get_param("default_graphics", "spice")
+        self.default_hvs = _split_list(_get_param("default_hvs", ""))
 
-preferred_distros = _split_list(_get_param("preferred_distros", ""))
-hv_packages = _split_list(_get_param("hv_packages", ""))
-askpass_package = _split_list(_get_param("askpass_packages", ""))
-libvirt_packages = _split_list(_get_param("libvirt_packages", ""))
-default_graphics = _get_param("default_graphics", "spice")
-with_bhyve = bool(int(_get_param("with_bhyve", "0")))
+        self.prefix = None
+        self.gettext_dir = None
+        self.ui_dir = None
+        self.icon_dir = None
+        self.set_paths_by_prefix(_get_param("prefix", "/usr/local"),
+            check_source_dir=True)
+
+    def set_paths_by_prefix(self, prefix, check_source_dir=False):
+        self.prefix = prefix
+        self.gettext_dir = os.path.join(prefix, "share", "locale")
+
+        if _running_from_srcdir and check_source_dir:
+            self.icon_dir = os.path.join(_srcdir, "data")
+            self.ui_dir = os.path.join(_srcdir, "ui")
+            _setup_gsettings_path(self.icon_dir)
+        else:
+            self.icon_dir = os.path.join(prefix, "share", "virt-manager",
+                "icons")
+            self.ui_dir = os.path.join(prefix, "share", "virt-manager", "ui")
+
+
+CLIConfig = _CLIConfig()
